==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QTextDecoder_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(textcodec)
#include <QtCore/qtextcodec.h>
#endif //QT_CONFIG(textcodec)
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(textcodec)


void deleter_QTextDecoder(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextDecoder")
    QTextDecoder *_ptr = reinterpret_cast<QTextDecoder *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(textcodec)

// emitting (writeConstructors)
// new QTextDecoder(const QTextCodec*)
void __qt_construct_QTextDecoder_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextDecoder(const QTextCodec*)")
#if QT_CONFIG(textcodec)
    jobject codec0 = __java_arguments[0].l;
    const QTextCodec* __qt_codec0 = qtjambi_cast<const QTextCodec* >(__jni_env, codec0);
    QTextDecoder *__qt_this = new(__qtjambi_ptr) QTextDecoder(__qt_codec0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
}

// new QTextDecoder(const QTextCodec*,QTextCodec::ConversionFlags)
void __qt_construct_QTextDecoder_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextDecoder(const QTextCodec*,QTextCodec::ConversionFlags)")
#if QT_CONFIG(textcodec)
    jobject codec0 = __java_arguments[0].l;
    const QTextCodec* __qt_codec0 = qtjambi_cast<const QTextCodec* >(__jni_env, codec0);
    jobject flags1 = __java_arguments[1].l;
    QTextCodec::ConversionFlags __qt_flags1 = qtjambi_cast<QTextCodec::ConversionFlags>(__jni_env, flags1);
    QTextDecoder *__qt_this = new(__qtjambi_ptr) QTextDecoder(__qt_codec0, QTextCodec::ConversionFlags(__qt_flags1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
}

// destruct QTextDecoder
void __qt_destruct_QTextDecoder(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextDecoder")

#if QT_CONFIG(textcodec)

    reinterpret_cast<QTextDecoder*>(ptr)->~QTextDecoder();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(textcodec)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextDecoder::QTextDecoder(const QTextCodec*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_initialize_1native__Lio_qt_core_QTextDecoder_2Lio_qt_core_QTextCodec_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject codec0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextDecoder::QTextDecoder(const QTextCodec*)")
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        jvalue arguments;
        arguments.l = codec0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextDecoder_0, sizeof(QTextDecoder), typeid(QTextDecoder), false, &deleter_QTextDecoder, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(codec0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextDecoder::QTextDecoder(const QTextCodec*,QTextCodec::ConversionFlags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_initialize_1native__Lio_qt_core_QTextDecoder_2Lio_qt_core_QTextCodec_2Lio_qt_core_QTextCodec_00024ConversionFlags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject codec0,
 jobject flags1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextDecoder::QTextDecoder(const QTextCodec*,QTextCodec::ConversionFlags)")
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        jvalue arguments[2];
        arguments[0].l = codec0;
        arguments[1].l = flags1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextDecoder_1, sizeof(QTextDecoder), typeid(QTextDecoder), false, &deleter_QTextDecoder, arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(codec0)
        Q_UNUSED(flags1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextDecoder::hasFailure()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_hasFailure_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        const QTextDecoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextDecoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextDecoder::hasFailure()const", __qt_this)
        __java_return_value = __qt_this->hasFailure();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextDecoder::needsMoreData()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_needsMoreData_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        const QTextDecoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextDecoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextDecoder::needsMoreData()const", __qt_this)
        __java_return_value = __qt_this->needsMoreData();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextDecoder::toUnicode(QByteArray)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_toUnicode_1native_1cref_1QByteArray__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID ba0)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        QTextDecoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextDecoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextDecoder::toUnicode(QByteArray)", __qt_this)
        const QByteArray& __qt_ba0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(ba0);
        QString __qt_return_value = __qt_this->toUnicode(__qt_ba0);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(ba0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTextDecoder(){
    using namespace RegistryAPI;

#if QT_CONFIG(textcodec)

    const std::type_info& typeId = registerObjectTypeInfo<QTextDecoder>("QTextDecoder", "io/qt/core/QTextDecoder");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextDecoder, {
        ConstructorInfo(&__qt_construct_QTextDecoder_0, "Lio/qt/core/QTextCodec;")
       ,ConstructorInfo(&__qt_construct_QTextDecoder_1, "Lio/qt/core/QTextCodec;Lio/qt/core/QTextCodec$ConversionFlags;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextDecoder);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(textcodec)

}

==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiCore/QTextDecoder_shell.cpp <==
#include <QtCore/QtGlobal>
#include <qtcore-config.h>
#if QT_CONFIG(textcodec)
#include <QtCore/qtextcodec.h>
#endif //QT_CONFIG(textcodec)
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qstring.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(textcodec)


void deleter_QTextDecoder(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTextDecoder")
    QTextDecoder *_ptr = reinterpret_cast<QTextDecoder *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}


#endif // QT_CONFIG(textcodec)

// emitting (writeConstructors)
// new QTextDecoder(const QTextCodec*)
void __qt_construct_QTextDecoder_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextDecoder(const QTextCodec*)")
#if QT_CONFIG(textcodec)
    jobject codec0 = __java_arguments[0].l;
    const QTextCodec* __qt_codec0 = qtjambi_cast<const QTextCodec* >(__jni_env, codec0);
    QTextDecoder *__qt_this = new(__qtjambi_ptr) QTextDecoder(__qt_codec0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
}

// new QTextDecoder(const QTextCodec*,QTextCodec::ConversionFlags)
void __qt_construct_QTextDecoder_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTextDecoder(const QTextCodec*,QTextCodec::ConversionFlags)")
#if QT_CONFIG(textcodec)
    jobject codec0 = __java_arguments[0].l;
    const QTextCodec* __qt_codec0 = qtjambi_cast<const QTextCodec* >(__jni_env, codec0);
    jobject flags1 = __java_arguments[1].l;
    QTextCodec::ConversionFlags __qt_flags1 = qtjambi_cast<QTextCodec::ConversionFlags>(__jni_env, flags1);
    QTextDecoder *__qt_this = new(__qtjambi_ptr) QTextDecoder(__qt_codec0, QTextCodec::ConversionFlags(__qt_flags1));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
}

// destruct QTextDecoder
void __qt_destruct_QTextDecoder(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTextDecoder")

#if QT_CONFIG(textcodec)

    reinterpret_cast<QTextDecoder*>(ptr)->~QTextDecoder();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(textcodec)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTextDecoder::QTextDecoder(const QTextCodec*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_initialize_1native__Lio_qt_core_QTextDecoder_2Lio_qt_core_QTextCodec_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject codec0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextDecoder::QTextDecoder(const QTextCodec*)")
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        jvalue arguments;
        arguments.l = codec0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextDecoder_0, sizeof(QTextDecoder), typeid(QTextDecoder), false, &deleter_QTextDecoder, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(codec0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextDecoder::QTextDecoder(const QTextCodec*,QTextCodec::ConversionFlags)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_initialize_1native__Lio_qt_core_QTextDecoder_2Lio_qt_core_QTextCodec_2Lio_qt_core_QTextCodec_00024ConversionFlags_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject codec0,
 jobject flags1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTextDecoder::QTextDecoder(const QTextCodec*,QTextCodec::ConversionFlags)")
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        jvalue arguments[2];
        arguments[0].l = codec0;
        arguments[1].l = flags1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTextDecoder_1, sizeof(QTextDecoder), typeid(QTextDecoder), false, &deleter_QTextDecoder, arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(codec0)
        Q_UNUSED(flags1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextDecoder::hasFailure()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_hasFailure_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        const QTextDecoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextDecoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextDecoder::hasFailure()const", __qt_this)
        __java_return_value = __qt_this->hasFailure();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextDecoder::needsMoreData()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_needsMoreData_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        const QTextDecoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextDecoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextDecoder::needsMoreData()const", __qt_this)
        __java_return_value = __qt_this->needsMoreData();
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextDecoder::toUnicode(QByteArray)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_toUnicode_1native_1cref_1QByteArray__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID ba0)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        QTextDecoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextDecoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextDecoder::toUnicode(QByteArray)", __qt_this)
        const QByteArray& __qt_ba0 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(ba0);
        QString __qt_return_value = __qt_this->toUnicode(__qt_ba0);
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(ba0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTextDecoder::toUnicode(QString*,const char*,int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_toUnicode_1native_1QString_1ptr_1const_1char_1ptr_1int__JLio_qt_core_QString_2Ljava_nio_ByteBuffer_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject target0,
 jstring chars1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        QTextDecoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextDecoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextDecoder::toUnicode(QString*,const char*,int)", __qt_this)
        int len2{0};
        QString*  __qt_target0 = qtjambi_cast<QString*>(__jni_env, target0);
        JBufferConstData __qt_chars1_buffer(__jni_env, chars1);
        const char* __qt_chars1 = __qt_chars1_buffer.data<char>();
        len2 = __qt_chars1_buffer.size<char>();
        __qt_this->toUnicode(__qt_target0, __qt_chars1, static_cast<int>(len2));
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(target0)
        Q_UNUSED(chars1)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTextDecoder::toUnicode(const char*,int)
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTextDecoder_toUnicode_1native_1const_1char_1ptr_1int__JLjava_nio_ByteBuffer_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring chars0)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(textcodec)
        QTextDecoder *__qt_this = QtJambiAPI::objectFromNativeId<QTextDecoder>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTextDecoder::toUnicode(const char*,int)", __qt_this)
        int len1{0};
        JBufferConstData __qt_chars0_buffer(__jni_env, chars0);
        const char* __qt_chars0 = __qt_chars0_buffer.data<char>();
        len1 = __qt_chars0_buffer.size<char>();
        QString __qt_return_value = __qt_this->toUnicode(__qt_chars0, static_cast<int>(len1));
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(chars0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(textcodec)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTextDecoder(){
    using namespace RegistryAPI;

#if QT_CONFIG(textcodec)

    const std::type_info& typeId = registerObjectTypeInfo<QTextDecoder>("QTextDecoder", "io/qt/core/QTextDecoder");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTextDecoder, {
        ConstructorInfo(&__qt_construct_QTextDecoder_0, "Lio/qt/core/QTextCodec;")
       ,ConstructorInfo(&__qt_construct_QTextDecoder_1, "Lio/qt/core/QTextCodec;Lio/qt/core/QTextCodec$ConversionFlags;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTextDecoder);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(textcodec)

}
